import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sts-db-utils-tj", # Replace with your own username
    version="0.0.2",
    author="tj",
    author_email="tjbindseil@gmail.com",
    description="used to connect to the database",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tbindseil/sts-mono-repo",
    package_dir={'': 'src'},  # Optional
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[],
    # TODO install_requires=['python-jose', 'requests'],
    python_requires='>=3.6',
)
